#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-QUnixTerminalImpl.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/qterminal/libqterminal/unix/moc-QUnixTerminalImpl.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-QUnixTerminalImpl.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QUnixTerminalImpl_t {
    QByteArrayData data[7];
    char stringdata0[92];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QUnixTerminalImpl_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QUnixTerminalImpl_t qt_meta_stringdata_QUnixTerminalImpl = {
    {
QT_MOC_LITERAL(0, 0, 17), // "QUnixTerminalImpl"
QT_MOC_LITERAL(1, 18, 13), // "copyClipboard"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 14), // "pasteClipboard"
QT_MOC_LITERAL(4, 48, 9), // "selectAll"
QT_MOC_LITERAL(5, 58, 25), // "handle_visibility_changed"
QT_MOC_LITERAL(6, 84, 7) // "visible"

    },
    "QUnixTerminalImpl\0copyClipboard\0\0"
    "pasteClipboard\0selectAll\0"
    "handle_visibility_changed\0visible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QUnixTerminalImpl[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x0a /* Public */,
       3,    0,   35,    2, 0x0a /* Public */,
       4,    0,   36,    2, 0x0a /* Public */,
       5,    1,   37,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    6,

       0        // eod
};

void QUnixTerminalImpl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QUnixTerminalImpl *_t = static_cast<QUnixTerminalImpl *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->copyClipboard(); break;
        case 1: _t->pasteClipboard(); break;
        case 2: _t->selectAll(); break;
        case 3: _t->handle_visibility_changed((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject QUnixTerminalImpl::staticMetaObject = {
    { &QTerminal::staticMetaObject, qt_meta_stringdata_QUnixTerminalImpl.data,
      qt_meta_data_QUnixTerminalImpl,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *QUnixTerminalImpl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QUnixTerminalImpl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QUnixTerminalImpl.stringdata0))
        return static_cast<void*>(this);
    return QTerminal::qt_metacast(_clname);
}

int QUnixTerminalImpl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTerminal::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
